cumulusci.robotframework package
================================

Submodules
----------

cumulusci.robotframework.CumulusCI module
-----------------------------------------

.. automodule:: cumulusci.robotframework.CumulusCI
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.robotframework.Salesforce module
------------------------------------------

.. automodule:: cumulusci.robotframework.Salesforce
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.robotframework.locators module
----------------------------------------

.. automodule:: cumulusci.robotframework.locators
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.robotframework.utils module
-------------------------------------

.. automodule:: cumulusci.robotframework.utils
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: cumulusci.robotframework
    :members:
    :undoc-members:
    :show-inheritance:
